Metadata entity
===============
.. currentmodule:: biobroker.metadata_entity

.. autosummary::
   :nosignatures:

    GenericEntity
    Biosample


.. automodule:: biobroker.metadata_entity
   :members:
   :undoc-members:
   :show-inheritance:


Exceptions
----------

.. automodule:: biobroker.metadata_entity.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
